@@ -1,20 +1,18 @@
 # coding=utf-8
-'''
-pymaze
-Copyright (C) 2012-2014 Moses Palmér
-
-This program is free software: you can redistribute it and/or modify it under
-the terms of the GNU General Public License as published by the Free Software
-Foundation, either version 3 of the License, or (at your option) any later
-version.
-
-This program is distributed in the hope that it will be useful, but WITHOUT ANY
-WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
-PARTICULAR PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-this program. If not, see <http://www.gnu.org/licenses/>.
-'''
+# pymaze
+# Copyright (C) 2012-2014 Moses Palmér
+#
+# This program is free software: you can redistribute it and/or modify it under
+# the terms of the GNU General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any later
+# version.
+#
+# This program is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# this program. If not, see <http://www.gnu.org/licenses/>.
 
 import math
 import os
@@ -39,6 +37,7 @@ from maze.randomized_prim import initialize
 from .terminal import print_maze
 from .image import make_image
 
+
 def main():
     import argparse
 
@@ -247,4 +246,3 @@ def main():
             (name.split('_', 1)[1], value)
                 for name, value in vars(namespace).items()
                 if name.startswith('image_')))
-
